==> activity-center-api-0.12.33-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/SkinTemplateDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

import java.util.List;

/**
 * ClassName: SkinTemplateDataDto <br/>
 * Function: 皮肤模板Dto. <br/>
 * date: 2017年2月24日 下午2:55:44 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class SkinTemplateDataDto extends BaseDto {

    private static final long serialVersionUID = 4927177308232082392L;

    private Long              id;                                     // 皮肤模板id
    private String            skinName;                               // 皮肤模板名称
    private Integer           templateType;                           // 皮肤模板类型
    private Integer           joinInType;                             // 接入类型
    private Integer           activityTemplateType;                   // 皮肤模板类型 区分自定义活动，直投页
    private Boolean           isDeleted;                              // 皮肤模板类型
    private String            skinType;                               // 模板标识
    private String            previewImg;                             // 预览图url
    private String            dataConfig;                             // 默认数据配置
    private String            styleConfig;                            // 默认样式配置
    private String            htmlConfig;                             // 活动自定义皮肤
    private Integer           newLayerRate;                           // 新弹层占比
    private Long              aLayerId;                               //a弹层id
    private Long              bLayerId;                               //b弹层id
    private String            aImage;                                 //a弹层预览图
    private String            bImage;                                 //b弹层预览图
    private Integer           isEnc;                                  //皮肤是否支持增值
    private Integer           isLayer;                                  //皮肤是否支持弹层
    private Integer           secondOpen;                                //皮肤是否支持二次增值
    private Integer           secondCollectAll;                           //皮肤二次增值个数
    private Integer           isFirstTicket;                           //是否首次发券 0-否 1-是
    private Integer isShowTitleFirst; // 是否展示主标题（默认0不展示,1展示）
    private Integer titleFirstLength; // 主标题长度限制（12字数之内，英文0.5中文1）")
    private Integer isShowTitleSecond;
    private Integer titleSecondLength;

    private List<SkinLayerDto> layerList;

    /** 是否支持预发券，0-否，1-是 */
    private Integer isPreAdvert;
    /** 预发券数量 */
    private Integer preAdvertNum;
    /** 新行业标签名称 */
    private String industryTagName;

    /** 特殊客服样式 当前只为联通 */
    private Integer speKeFuStyle;

    /** 标题、奖品组件化开关 */
    private Integer subSwitch;

    /** 素材类型: 0=普通类型, 1=SVGA类型, 2=动效 */
    private Integer format;
    /** 皮肤是否展示，1：展示，0：不展示 */
    private Integer isShow;

    private Integer isDeepSkin;

    public Integer getIsShow() {
        return isShow;
    }

    public void setIsShow(Integer isShow) {
        this.isShow = isShow;
    }

    public Integer getIsPreAdvert() {
        return isPreAdvert;
    }

    public void setIsPreAdvert(Integer isPreAdvert) {
        this.isPreAdvert = isPreAdvert;
    }

    public Integer getPreAdvertNum() {
        return preAdvertNum;
    }

    public void setPreAdvertNum(Integer preAdvertNum) {
        this.preAdvertNum = preAdvertNum;
    }

    public String getIndustryTagName() {
        return industryTagName;
    }

    public void setIndustryTagName(String industryTagName) {
        this.industryTagName = industryTagName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getPreviewImg() {
        return previewImg;
    }

    public void setPreviewImg(String previewImg) {
        this.previewImg = previewImg;
    }

    public String getDataConfig() {
        return dataConfig;
    }

    public void setDataConfig(String dataConfig) {
        this.dataConfig = dataConfig;
    }

    public String getStyleConfig() {
        return styleConfig;
    }

    public void setStyleConfig(String styleConfig) {
        this.styleConfig = styleConfig;
    }

    public String getHtmlConfig() {
        return htmlConfig;
    }

    public void setHtmlConfig(String htmlConfig) {
        this.htmlConfig = htmlConfig;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }
    
    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }

    public String getaImage() {
        return aImage;
    }

    public void setaImage(String aImage) {
        this.aImage = aImage;
    }

    public String getbImage() {
        return bImage;
    }

    public void setbImage(String bImage) {
        this.bImage = bImage;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public List<SkinLayerDto> getLayerList() {
        return layerList;
    }

    public void setLayerList(List<SkinLayerDto> layerList) {
        this.layerList = layerList;
    }

    public Integer getActivityTemplateType() {
        return activityTemplateType;
    }

    public void setActivityTemplateType(Integer activityTemplateType) {
        this.activityTemplateType = activityTemplateType;
    }

    public Integer getJoinInType() {
        return joinInType;
    }

    public void setJoinInType(final Integer joinInType) {
        this.joinInType = joinInType;
    }

    public Integer getIsLayer() {
        return isLayer;
    }

    public void setIsLayer(Integer isLayer) {
        this.isLayer = isLayer;
    }

    public Integer getSecondOpen() {
        return secondOpen;
    }

    public void setSecondOpen(final Integer secondOpen) {
        this.secondOpen = secondOpen;
    }

    public Integer getSecondCollectAll() {
        return secondCollectAll;
    }

    public void setSecondCollectAll(final Integer secondCollectAll) {
        this.secondCollectAll = secondCollectAll;
    }

    public Integer getIsFirstTicket() {
        return isFirstTicket;
    }

    public void setIsFirstTicket(Integer isFirstTicket) {
        this.isFirstTicket = isFirstTicket;
    }

    public Integer getIsShowTitleFirst() {
        return isShowTitleFirst;
    }

    public void setIsShowTitleFirst(Integer isShowTitleFirst) {
        this.isShowTitleFirst = isShowTitleFirst;
    }

    public Integer getTitleFirstLength() {
        return titleFirstLength;
    }

    public void setTitleFirstLength(Integer titleFirstLength) {
        this.titleFirstLength = titleFirstLength;
    }

    public Integer getIsShowTitleSecond() {
        return isShowTitleSecond;
    }

    public void setIsShowTitleSecond(Integer isShowTitleSecond) {
        this.isShowTitleSecond = isShowTitleSecond;
    }

    public Integer getTitleSecondLength() {
        return titleSecondLength;
    }

    public void setTitleSecondLength(Integer titleSecondLength) {
        this.titleSecondLength = titleSecondLength;
    }

    public Integer getSpeKeFuStyle() {
        return speKeFuStyle;
    }

    public void setSpeKeFuStyle(final Integer speKeFuStyle) {
        this.speKeFuStyle = speKeFuStyle;
    }

    public Integer getSubSwitch() {
        return subSwitch;
    }

    public void setSubSwitch(Integer subSwitch) {
        this.subSwitch = subSwitch;
    }

    public Integer getFormat() {
        return format;
    }

    public void setFormat(Integer format) {
        this.format = format;
    }

    public Integer getIsDeepSkin() {
        return isDeepSkin;
    }

    public void setIsDeepSkin(Integer isDeepSkin) {
        this.isDeepSkin = isDeepSkin;
    }
}

==> activity-center-api-0.16.62-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/SkinTemplateDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

import java.util.List;

/**
 * ClassName: SkinTemplateDataDto <br/>
 * Function: 皮肤模板Dto. <br/>
 * date: 2017年2月24日 下午2:55:44 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class SkinTemplateDataDto extends BaseDto {

    private static final long serialVersionUID = 4927177308232082392L;

    private Long              id;                                     // 皮肤模板id
    private String            skinName;                               // 皮肤模板名称
    private Integer           templateType;                           // 皮肤模板类型
    private Integer           joinInType;                             // 接入类型
    private Integer           activityTemplateType;                   // 皮肤模板类型 区分自定义活动，直投页
    private Boolean           isDeleted;                              // 皮肤模板类型
    private String            skinType;                               // 模板标识
    private String            previewImg;                             // 预览图url
    private String            dataConfig;                             // 默认数据配置
    private String            styleConfig;                            // 默认样式配置
    private String            htmlConfig;                             // 活动自定义皮肤
    private Integer           newLayerRate;                           // 新弹层占比
    private Long              aLayerId;                               //a弹层id
    private Long              bLayerId;                               //b弹层id
    private String            aImage;                                 //a弹层预览图
    private String            bImage;                                 //b弹层预览图
    private Integer           isEnc;                                  //皮肤是否支持增值
    private Integer           isLayer;                                  //皮肤是否支持弹层
    private Integer           secondOpen;                                //皮肤是否支持二次增值
    private Integer           secondCollectAll;                           //皮肤二次增值个数
    private Integer           isFirstTicket;                           //是否首次发券 0-否 1-是
    private Integer isShowTitleFirst; // 是否展示主标题（默认0不展示,1展示）
    private Integer titleFirstLength; // 主标题长度限制（12字数之内，英文0.5中文1）")
    private Integer isShowTitleSecond;
    private Integer titleSecondLength;

    private List<SkinLayerDto> layerList;

    /** 是否支持预发券，0-否，1-是 */
    private Integer isPreAdvert;
    /** 预发券数量 */
    private Integer preAdvertNum;
    /** 新行业标签名称 */
    private String industryTagName;

    /** 特殊客服样式 当前只为联通 */
    private Integer speKeFuStyle;

    /** 标题、奖品组件化开关 */
    private Integer subSwitch;

    /** 素材类型: 0=普通类型, 1=SVGA类型, 2=动效 */
    private Integer format;
    /** 皮肤是否展示，1：展示，0：不展示 */
    private Integer isShow;

    private Integer isDeepSkin;

    /** 是否出激励视频*/
    private Integer isShowRewardVideo;

    /** 皮肤备注*/
    private String remark;

    /**
     * 宝箱及动效展示 0-否 1-是
     */
    private Integer isDynamicEffectDisplay;

    public Integer getIsDynamicEffectDisplay() {
        return isDynamicEffectDisplay;
    }

    public void setIsDynamicEffectDisplay(Integer isDynamicEffectDisplay) {
        this.isDynamicEffectDisplay = isDynamicEffectDisplay;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getIsShow() {
        return isShow;
    }

    public void setIsShow(Integer isShow) {
        this.isShow = isShow;
    }

    public Integer getIsPreAdvert() {
        return isPreAdvert;
    }

    public void setIsPreAdvert(Integer isPreAdvert) {
        this.isPreAdvert = isPreAdvert;
    }

    public Integer getPreAdvertNum() {
        return preAdvertNum;
    }

    public void setPreAdvertNum(Integer preAdvertNum) {
        this.preAdvertNum = preAdvertNum;
    }

    public String getIndustryTagName() {
        return industryTagName;
    }

    public void setIndustryTagName(String industryTagName) {
        this.industryTagName = industryTagName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getPreviewImg() {
        return previewImg;
    }

    public void setPreviewImg(String previewImg) {
        this.previewImg = previewImg;
    }

    public String getDataConfig() {
        return dataConfig;
    }

    public void setDataConfig(String dataConfig) {
        this.dataConfig = dataConfig;
    }

    public String getStyleConfig() {
        return styleConfig;
    }

    public void setStyleConfig(String styleConfig) {
        this.styleConfig = styleConfig;
    }

    public String getHtmlConfig() {
        return htmlConfig;
    }

    public void setHtmlConfig(String htmlConfig) {
        this.htmlConfig = htmlConfig;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }

    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }

    public String getaImage() {
        return aImage;
    }

    public void setaImage(String aImage) {
        this.aImage = aImage;
    }

    public String getbImage() {
        return bImage;
    }

    public void setbImage(String bImage) {
        this.bImage = bImage;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public List<SkinLayerDto> getLayerList() {
        return layerList;
    }

    public void setLayerList(List<SkinLayerDto> layerList) {
        this.layerList = layerList;
    }

    public Integer getActivityTemplateType() {
        return activityTemplateType;
    }

    public void setActivityTemplateType(Integer activityTemplateType) {
        this.activityTemplateType = activityTemplateType;
    }

    public Integer getJoinInType() {
        return joinInType;
    }

    public void setJoinInType(final Integer joinInType) {
        this.joinInType = joinInType;
    }

    public Integer getIsLayer() {
        return isLayer;
    }

    public void setIsLayer(Integer isLayer) {
        this.isLayer = isLayer;
    }

    public Integer getSecondOpen() {
        return secondOpen;
    }

    public void setSecondOpen(final Integer secondOpen) {
        this.secondOpen = secondOpen;
    }

    public Integer getSecondCollectAll() {
        return secondCollectAll;
    }

    public void setSecondCollectAll(final Integer secondCollectAll) {
        this.secondCollectAll = secondCollectAll;
    }

    public Integer getIsFirstTicket() {
        return isFirstTicket;
    }

    public void setIsFirstTicket(Integer isFirstTicket) {
        this.isFirstTicket = isFirstTicket;
    }

    public Integer getIsShowTitleFirst() {
        return isShowTitleFirst;
    }

    public void setIsShowTitleFirst(Integer isShowTitleFirst) {
        this.isShowTitleFirst = isShowTitleFirst;
    }

    public Integer getTitleFirstLength() {
        return titleFirstLength;
    }

    public void setTitleFirstLength(Integer titleFirstLength) {
        this.titleFirstLength = titleFirstLength;
    }

    public Integer getIsShowTitleSecond() {
        return isShowTitleSecond;
    }

    public void setIsShowTitleSecond(Integer isShowTitleSecond) {
        this.isShowTitleSecond = isShowTitleSecond;
    }

    public Integer getTitleSecondLength() {
        return titleSecondLength;
    }

    public void setTitleSecondLength(Integer titleSecondLength) {
        this.titleSecondLength = titleSecondLength;
    }

    public Integer getSpeKeFuStyle() {
        return speKeFuStyle;
    }

    public void setSpeKeFuStyle(final Integer speKeFuStyle) {
        this.speKeFuStyle = speKeFuStyle;
    }

    public Integer getSubSwitch() {
        return subSwitch;
    }

    public void setSubSwitch(Integer subSwitch) {
        this.subSwitch = subSwitch;
    }

    public Integer getFormat() {
        return format;
    }

    public void setFormat(Integer format) {
        this.format = format;
    }

    public Integer getIsDeepSkin() {
        return isDeepSkin;
    }

    public void setIsDeepSkin(Integer isDeepSkin) {
        this.isDeepSkin = isDeepSkin;
    }

    public Integer getIsShowRewardVideo() {
        return isShowRewardVideo;
    }

    public void setIsShowRewardVideo(Integer isShowRewardVideo) {
        this.isShowRewardVideo = isShowRewardVideo;
    }
}
